@@ -2,6 +2,7 @@
 
 import functools
 import logging
+import time
 import urllib.parse
 from http.server import HTTPServer
 from ipaddress import IPv4Address, IPv4Network
@@ -15,8 +16,10 @@ import ifaddr
 from RangeHTTPServer import RangeRequestHandler
 
 from soco_cli.utils import (
+    add_sub,
     error_report,
     event_unsubscribe,
+    remove_sub,
     set_sigterm,
     set_speaker_playing_local_file,
 )
@@ -25,7 +28,7 @@ from soco_cli.utils import (
 PORT_START = 54000
 PORT_END = 54099
 
-SUPPORTED_TYPES = ["MP3", "M4A", "MP4", "FLAC", "OGG", "WMA", "WAV", "AAC"]
+SUPPORTED_TYPES = ["MP3", "M4A", "MP4", "FLAC", "OGG", "WMA", "WAV"]
 
 # Need to know whether this is Python >= 3.7
 PY37PLUS = bool((pyversion.major == 3 and pyversion.minor >= 7) or pyversion.major > 3)
@@ -132,23 +135,31 @@ def get_server_ip(speaker):
     return None
 
 
-def wait_until_stopped(speaker, uri, aac_file=False):
-    sub = speaker.avTransport.subscribe(auto_renew=True)
-    # Includes a hack for AAC files, which would be played in a repeat loop.
-    # The speaker never goes into a 'STOPPED' state, so we have
-    # to detect the shift into a 'TRANSITIONING' state after playback
-    has_played = False
+def wait_until_stopped(speaker, uri):
+    playing_states = ["PLAYING", "TRANSITIONING", "PAUSED_PLAYBACK"]
+    try:
+        sub = speaker.avTransport.subscribe(auto_renew=True)
+        add_sub(sub)
+    except Exception as e:
+        error_report("Exception {}".format(e))
+        return
+
+    set_sigterm(True)
     while True:
         try:
             event = sub.events.get(timeout=1.0)
-            logging.info(
-                "Transport event: State = '{}'".format(
-                    event.variables["transport_state"]
-                )
-            )
+            state = event.variables["transport_state"]
+            logging.info("Event received: playback state = '{}'".format(state))
 
-            # In case there's no STOPPED state event, check that the expected URI
-            # is still playing
+            if state not in playing_states:
+                logging.info(
+                    "Speaker '{}' in state '{}'".format(
+                        speaker.player_name, event.variables["transport_state"]
+                    )
+                )
+                break
+
+            # Check that the expected URI is still playing
             try:
                 current_uri = event.variables["current_track_meta_data"].get_uri()
             except:
@@ -156,32 +167,16 @@ def wait_until_stopped(speaker, uri, aac_file=False):
                 current_uri = ""
             if current_uri != uri:
                 logging.info("Playback URI changed: exit event wait loop")
-                event_unsubscribe(sub)
-                return True
+                break
 
-            # Special case for AAC files
-            if aac_file:
-                if event.variables["transport_state"] == "TRANSITIONING":
-                    logging.info("Transitioning event received")
-                    if has_played:
-                        logging.info("AAC: transition event indicating end of track")
-                        event_unsubscribe(sub)
-                        speaker.stop()
-                        return True
-                    logging.info("AAC: transition event before playback")
-                if event.variables["transport_state"] == "PLAYING":
-                    has_played = True
-                    logging.info("AAC: has_played set to True")
-
-            # General case for other file types. Note that pausing (PAUSED_PLAYBACK)
-            # does not terminate the loop, to allow playback to be resumed
-            if event.variables["transport_state"] == "STOPPED":
-                event_unsubscribe(sub)
-                return True
-
-        except Empty:
+        except:
             pass
 
+    event_unsubscribe(sub)
+    remove_sub(sub)
+    set_sigterm(False)
+    return
+
 
 def is_supported_type(filename):
     file_upper = filename.upper()
@@ -236,33 +231,20 @@ def play_local_file(speaker, pathname):
     logging.info("Playing file '{}' from directory '{}'".format(filename, directory))
     logging.info("Playback URI: {}".format(uri))
 
-    # Send the URI to the speaker for playback
-    # A special hack is required for AAC files, which have to be treated like radio.
-    if filename.lower().endswith(".aac"):
-        aac_file = True
-        # speaker.play_uri(uri, force_radio=True)
-        speaker.play_uri(uri)
-    else:
-        aac_file = False
-        speaker.play_uri(uri)
+    logging.info("Send URI to '{}' for playback".format(speaker.player_name))
+    speaker.play_uri(uri)
 
     logging.info("Setting flag to stop playback on CTRL-C")
     set_speaker_playing_local_file(speaker)
 
+    logging.info("Waiting 3s for playback to start")
+    time.sleep(3.0)
     logging.info("Waiting for playback to stop")
-    # SIGTERM enablement experiment for AAC files only
-    # Also needed for Python < 3.7
-    if aac_file or not PY37PLUS:
-        set_sigterm(True)
-        wait_until_stopped(speaker, uri, aac_file=aac_file)
-        set_sigterm(False)
-    else:
-        wait_until_stopped(speaker, uri, aac_file=aac_file)
-
+    wait_until_stopped(speaker, uri)
     logging.info("Playback stopped ... terminating web server")
     httpd.shutdown()
-
     logging.info("Web server terminated")
+
     set_speaker_playing_local_file(None)
 
     return True
