@@ -27,7 +27,7 @@ def event_unsubscribe(sub):
     # by yielding the thread
     pause_seconds = 0.2
     logging.info(
-        "Unsubscribing from events ... yield by pausing for {}s".format(pause_seconds)
+        "Unsubscribing ... yield by pausing for {}s".format(pause_seconds)
     )
     sleep(pause_seconds)
     sub.unsubscribe()
@@ -247,6 +247,7 @@ use_sigterm = False
 
 def set_sigterm(sigterm):
     global use_sigterm
+    logging.info("Setting 'use_sigterm' to '{}'".format(sigterm))
     use_sigterm = sigterm
 
 
@@ -256,6 +257,7 @@ suspend_sigterm = False
 
 def set_suspend_sigterm(suspend=True):
     global suspend_sigterm
+    logging.info("Setting 'suspend_sigterm' to '{}'".format(suspend))
     suspend_sigterm = suspend
 
 
@@ -265,6 +267,11 @@ speaker_playing_local_file = None
 
 def set_speaker_playing_local_file(speaker):
     global speaker_playing_local_file
+    if speaker:
+        logging.info("Speaker playing local file = '{}'".format(speaker.player_name))
+    else:
+        logging.info(
+            "Speaker playing local file = 'None'")
     speaker_playing_local_file = speaker
 
 
@@ -283,12 +290,18 @@ def sig_handler(signal_received, frame):
             speaker_playing_local_file.stop()
 
         if INTERACTIVE:
+            logging.info("Saving readline history")
             save_readline_history()
 
+        logging.info("Cleaning up subscriptions")
+        sub_unsub_all()
+
         # TODO: Temporary for now; hard kill required to get out of wait
         if use_sigterm:
+            logging.info("Using os.kill() with SIGTERM (hard kill) to exit")
             os.kill(os.getpid(), SIGTERM)
         else:
+            logging.info("Exiting program normally")
             exit(0)
 
 
@@ -784,3 +797,33 @@ def playback_state(state):
         return playback_mapping[state]
     except KeyError:
         return "unknown"
+
+
+# Ensure that event subscriptions are cleared on CTRL-C
+SUBS_LIST = set()
+
+
+def add_sub(sub):
+    global SUBS_LIST
+    logging.info("Adding event subscription: '{}'".format(sub))
+    SUBS_LIST.add(sub)
+
+
+def remove_sub(sub):
+    global SUBS_LIST
+    try:
+        logging.info("Removing event subscription: '{}'".format(sub))
+        SUBS_LIST.remove(sub)
+    except KeyError:
+        pass
+
+
+def sub_unsub_all():
+    global SUBS_LIST
+    for sub in SUBS_LIST:
+        try:
+            logging.info("Unsubscribing: '{}'".format(sub))
+            event_unsubscribe(sub)
+        except:
+            break
+    SUBS_LIST.clear()
